==> haskell-aws-0.20-77-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-aws.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aws
version: 0.20
id: aws-0.20-8Apsg6I6Hfa3C5GCYvoutC
key: aws-0.20-8Apsg6I6Hfa3C5GCYvoutC
license: BSD-3-Clause
copyright: See contributors list in README and LICENSE file
maintainer: aristidb@gmail.com
author: Aristid Breitkreuz, contributors see README
homepage: http://github.com/aristidb/aws
synopsis: Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.
category: Network, Web, AWS, Cloud, Distributed Computing
abi: bfb775c1837bc41b18d4b46fcf1709b8
exposed: True
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.BatchGetItem
    Aws.DynamoDb.Commands.BatchWriteItem
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.CreateAccessKey Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetUser
    Aws.Iam.Commands.GetUserPolicy Aws.Iam.Commands.ListAccessKeys
    Aws.Iam.Commands.ListMfaDevices Aws.Iam.Commands.ListUserPolicies
    Aws.Iam.Commands.ListUsers Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateUser
    Aws.Iam.Core Aws.Iam.Internal Aws.Network Aws.S3 Aws.S3.Commands
    Aws.S3.Commands.CopyObject Aws.S3.Commands.DeleteBucket
    Aws.S3.Commands.DeleteObject Aws.S3.Commands.DeleteObjectVersion
    Aws.S3.Commands.DeleteObjects Aws.S3.Commands.GetBucket
    Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.Multipart Aws.S3.Commands.PutBucket
    Aws.S3.Commands.PutObject Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core
import-dirs: /usr/lib/ghc-8.4.3/site-local/aws-0.20
library-dirs: /usr/lib/ghc-8.4.3/site-local/aws-0.20
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/aws-0.20
hs-libraries: HSaws-0.20-8Apsg6I6Hfa3C5GCYvoutC
depends:
    aeson-1.4.0.0-CakggGCi8AH730RFzdp4vh
    attoparsec-0.13.2.2-LRi8ukEwwi1GyId6oqTEFJ base-4.11.1.0
    base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028
    byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC
    conduit-1.3.0.3-69KoIVNx0TVLvOnjPWsVja
    conduit-extra-1.3.0-4j5DaXyKuirAJK9sh69vxz containers-0.5.11.0
    cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT
    data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0 directory-1.3.1.5
    filepath-1.4.2 http-conduit-2.3.2-Fc3FewYwyrU2z9C3xj29pG
    http-types-0.12.1-BvzC7WDeWNh7Q1bvrgnPmB
    lifted-base-0.2.3.12-KjumfQ58uBm8QT3h2l4nDA
    memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk
    monad-control-1.0.2.3-FfEOTMHoA2lIa1PKK0mtSB
    exceptions-0.10.0-KqLFUMgISLoDmBqq0VbkGc mtl-2.2.2
    network-2.7.0.2-8yE8vwBlEy1KZPVD4sTAn
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh
    resourcet-1.2.1-I5oi84Fds3fEsALgoQoNDA
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO text-1.2.3.0 time-1.8.0.2
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    xml-conduit-1.8.0-B3jRhN4FymgBxETDF0MfEe
abi-depends: aeson-1.4.0.0-CakggGCi8AH730RFzdp4vh=7bc5561c9bccdf225964aec1dc0920a0
             attoparsec-0.13.2.2-LRi8ukEwwi1GyId6oqTEFJ=b8f8a17746566009aae6e9799affc625
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh=bba358ad6d6aaa259e18cb7e07ede79c
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY=cdb4e7359967ea10cd00ae1d3fab6945
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC=5e7d9231d9563e623638bef60db7e501
             conduit-1.3.0.3-69KoIVNx0TVLvOnjPWsVja=95a17956f651b4cddf6ae026fd262ccd
             conduit-extra-1.3.0-4j5DaXyKuirAJK9sh69vxz=7890d00a08a10fe933f51da56482ec4e
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT=b157b67f4f829eb7de058ea2d8709fe0
             data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0=e2403b7ea90422302496191f03ca1dc3
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             http-conduit-2.3.2-Fc3FewYwyrU2z9C3xj29pG=587475ff466ed617e153f3e7b1f159a8
             http-types-0.12.1-BvzC7WDeWNh7Q1bvrgnPmB=302ec39836eeed635681d48972d58b60
             lifted-base-0.2.3.12-KjumfQ58uBm8QT3h2l4nDA=bb0bc40b0f20c1d20c198f711f59633a
             memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk=a0627d5d7afb3952e7ea8a317c372f9d
             monad-control-1.0.2.3-FfEOTMHoA2lIa1PKK0mtSB=96aa252ac60feebdbd0ad048336933d6
             exceptions-0.10.0-KqLFUMgISLoDmBqq0VbkGc=7e2a2010d6645bddac83e90b3cee8839
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             network-2.7.0.2-8yE8vwBlEy1KZPVD4sTAn=90fa8650caae170586ac66be24e6a39f
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=576647ddb2b9fe32850edc158395e14c
             resourcet-1.2.1-I5oi84Fds3fEsALgoQoNDA=dcbdc81671b5884f063aea7a644e0575
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=42026212d0dad8beaed25fde58365be8
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=15b9d897726264a79d0c84c8eea548d3
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd=4d1dd6bd73dbf55dc13ef767664a6e82
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=03d2b6edbbe4042d502eabc2ba3840fc
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             xml-conduit-1.8.0-B3jRhN4FymgBxETDF0MfEe=00626b7a116849b4cca79b99206c6ebd
haddock-interfaces: /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html: /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aws-0.20-79-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-aws.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aws
version: 0.20
id: aws-0.20-AMJvxNZS8AHmK0h0ETdiX
key: aws-0.20-AMJvxNZS8AHmK0h0ETdiX
license: BSD-3-Clause
copyright: See contributors list in README and LICENSE file
maintainer: aristidb@gmail.com
author: Aristid Breitkreuz, contributors see README
homepage: http://github.com/aristidb/aws
synopsis: Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.
category: Network, Web, AWS, Cloud, Distributed Computing
abi: 6890c730119981a27d966ab5ee2566c2
exposed: True
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.BatchGetItem
    Aws.DynamoDb.Commands.BatchWriteItem
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.CreateAccessKey Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetUser
    Aws.Iam.Commands.GetUserPolicy Aws.Iam.Commands.ListAccessKeys
    Aws.Iam.Commands.ListMfaDevices Aws.Iam.Commands.ListUserPolicies
    Aws.Iam.Commands.ListUsers Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateUser
    Aws.Iam.Core Aws.Iam.Internal Aws.Network Aws.S3 Aws.S3.Commands
    Aws.S3.Commands.CopyObject Aws.S3.Commands.DeleteBucket
    Aws.S3.Commands.DeleteObject Aws.S3.Commands.DeleteObjectVersion
    Aws.S3.Commands.DeleteObjects Aws.S3.Commands.GetBucket
    Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.Multipart Aws.S3.Commands.PutBucket
    Aws.S3.Commands.PutObject Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core
import-dirs: /usr/lib/ghc-8.4.3/site-local/aws-0.20
library-dirs: /usr/lib/ghc-8.4.3/site-local/aws-0.20
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/aws-0.20
hs-libraries: HSaws-0.20-AMJvxNZS8AHmK0h0ETdiX
depends:
    aeson-1.4.0.0-EgUTCbIlE19378rsR2i9zV
    attoparsec-0.13.2.2-LRi8ukEwwi1GyId6oqTEFJ base-4.11.1.0
    base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028
    byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC
    conduit-1.3.0.3-69KoIVNx0TVLvOnjPWsVja
    conduit-extra-1.3.0-4j5DaXyKuirAJK9sh69vxz containers-0.5.11.0
    cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT
    data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn directory-1.3.1.5
    filepath-1.4.2 http-conduit-2.3.2-1aZWoMRsYRpKfDlvvbX8BU
    http-types-0.12.1-BvzC7WDeWNh7Q1bvrgnPmB
    lifted-base-0.2.3.12-KjumfQ58uBm8QT3h2l4nDA
    memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk
    monad-control-1.0.2.3-FfEOTMHoA2lIa1PKK0mtSB
    exceptions-0.10.0-KqLFUMgISLoDmBqq0VbkGc mtl-2.2.2
    network-2.7.0.2-8yE8vwBlEy1KZPVD4sTAn
    old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh
    resourcet-1.2.1-I5oi84Fds3fEsALgoQoNDA
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO text-1.2.3.0 time-1.8.0.2
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    xml-conduit-1.8.0-B3jRhN4FymgBxETDF0MfEe
abi-depends: aeson-1.4.0.0-EgUTCbIlE19378rsR2i9zV=8e4d597de977510ba6167651bfbacc4c
             attoparsec-0.13.2.2-LRi8ukEwwi1GyId6oqTEFJ=b8f8a17746566009aae6e9799affc625
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh=bba358ad6d6aaa259e18cb7e07ede79c
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             byteable-0.1.1-APABKKN6nDlC3QxQBw4YlY=cdb4e7359967ea10cd00ae1d3fab6945
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC=5e7d9231d9563e623638bef60db7e501
             conduit-1.3.0.3-69KoIVNx0TVLvOnjPWsVja=95a17956f651b4cddf6ae026fd262ccd
             conduit-extra-1.3.0-4j5DaXyKuirAJK9sh69vxz=7890d00a08a10fe933f51da56482ec4e
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             cryptonite-0.25-FWytOeO7q1U1VcDN91QFfT=b157b67f4f829eb7de058ea2d8709fe0
             data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn=02e9419e0e877fc1db7c56d6f64866aa
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             http-conduit-2.3.2-1aZWoMRsYRpKfDlvvbX8BU=d9058125d1363db51383405558893120
             http-types-0.12.1-BvzC7WDeWNh7Q1bvrgnPmB=302ec39836eeed635681d48972d58b60
             lifted-base-0.2.3.12-KjumfQ58uBm8QT3h2l4nDA=bb0bc40b0f20c1d20c198f711f59633a
             memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk=a0627d5d7afb3952e7ea8a317c372f9d
             monad-control-1.0.2.3-FfEOTMHoA2lIa1PKK0mtSB=96aa252ac60feebdbd0ad048336933d6
             exceptions-0.10.0-KqLFUMgISLoDmBqq0VbkGc=7e2a2010d6645bddac83e90b3cee8839
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             network-2.7.0.2-8yE8vwBlEy1KZPVD4sTAn=90fa8650caae170586ac66be24e6a39f
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=576647ddb2b9fe32850edc158395e14c
             resourcet-1.2.1-I5oi84Fds3fEsALgoQoNDA=dcbdc81671b5884f063aea7a644e0575
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=42026212d0dad8beaed25fde58365be8
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=15b9d897726264a79d0c84c8eea548d3
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd=4d1dd6bd73dbf55dc13ef767664a6e82
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=03d2b6edbbe4042d502eabc2ba3840fc
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             xml-conduit-1.8.0-B3jRhN4FymgBxETDF0MfEe=00626b7a116849b4cca79b99206c6ebd
haddock-interfaces: /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html: /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
